@@ -6,11 +6,13 @@ pub mod net;
 pub mod procs;
 pub mod settings;
 
-use crate::gui::{message::Message, View};
-use fltk::group::Pack;
+use crate::gui::{message::Message, styles::colors::GRAY, View};
+use fltk::app;
 use parking_lot::Mutex;
-use std::sync::atomic::{AtomicBool, AtomicU64};
-use std::sync::Arc;
+use std::sync::{
+    atomic::{AtomicBool, AtomicU64, Ordering},
+    Arc,
+};
 use sysinfo::{System, SystemExt};
 
 #[repr(i32)]
@@ -37,20 +39,29 @@ pub struct MyView {
 
 impl Default for MyView {
     fn default() -> Self {
+        let mode = dark_light::detect() == dark_light::Mode::Light;
+        if mode {
+            app::foreground(50, 50, 50);
+            app::background(255, 255, 255);
+        } else {
+            app::foreground(255, 255, 255);
+            let (r, g, b) = GRAY.to_rgb();
+            app::background(r, g, b);
+        }
         let mut sys = System::new_all();
         sys.refresh_all();
         let system = Arc::new(Mutex::new(sys));
         Self {
             system,
-            sleep: Arc::new(AtomicU64::from(200)),
-            light_mode: Arc::new(AtomicBool::from(false)),
+            sleep: Arc::new(AtomicU64::from(300)),
+            light_mode: Arc::new(AtomicBool::from(mode)),
             ordering: Arc::new(Mutex::new(SortOrder::Pid)),
         }
     }
 }
 
 impl View for MyView {
-    fn view(&self, msg: Message) -> Pack {
+    fn view(&self, msg: Message) -> Option<Box<dyn FnMut() + Send>> {
         match msg {
             Message::General => self.general(),
             Message::Disks => self.disks(),
@@ -61,28 +72,34 @@ impl View for MyView {
             Message::Settings => self.settings(),
         }
     }
+    fn sleep_duration(&self) -> u64 {
+        self.sleep.load(Ordering::Relaxed)
+    }
+    fn light_mode(&self) -> bool {
+        self.light_mode.load(Ordering::Relaxed)
+    }
 }
 
 impl MyView {
-    pub fn general(&self) -> Pack {
+    pub fn general(&self) -> Option<Box<dyn FnMut() + Send>> {
         general::general(self)
     }
-    pub fn memory(&self) -> Pack {
+    pub fn memory(&self) -> Option<Box<dyn FnMut() + Send>> {
         mem::memory(self)
     }
-    pub fn settings(&self) -> Pack {
+    pub fn settings(&self) -> Option<Box<dyn FnMut() + Send>> {
         settings::settings(self)
     }
-    pub fn network(&self) -> Pack {
+    pub fn network(&self) -> Option<Box<dyn FnMut() + Send>> {
         net::network(self)
     }
-    pub fn cpu(&self) -> Pack {
+    pub fn cpu(&self) -> Option<Box<dyn FnMut() + Send>> {
         cpu::proc(self)
     }
-    pub fn disks(&self) -> Pack {
+    pub fn disks(&self) -> Option<Box<dyn FnMut() + Send>> {
         disk::disks(self)
     }
-    pub fn procs(&self) -> Pack {
+    pub fn procs(&self) -> Option<Box<dyn FnMut() + Send>> {
         procs::procs(self)
     }
 }
